@@ -40,9 +40,9 @@ def set_dataframe_columntypes(df):
         df['idLead'] = df['idLead'].astype('int32')
     if 'idCampaign' in df:
         df['idCampaign'] = df['idCampaign'].astype('int8')
-    if 'BulkStatus' in df:
-        df['BulkStatus']=df['BulkStatus'].astype('str')
-        df['BulkStatus'] = df['BulkStatus'].astype('object')
+    # if 'BulkStatus' in df:
+    #     df['BulkStatus']=df['BulkStatus'].astype('str')
+    #     df['BulkStatus'] = df['BulkStatus'].astype('object')
     if 'campaign_bulk_date' in df:
         df['campaign_bulk_date'] = df['campaign_bulk_date'].astype('object')
         df['campaign_bulk_date'] = pd.to_datetime(df['campaign_bulk_date'])
@@ -324,16 +324,18 @@ def filter_countries(df, countries,fixed_filter):
 
     return df
 
-def change_bulkstatus_to_string(df):
+def process_bulkstatus(df):
+    logger.info("Processing Bulk Status column")
     if 'BulkStatus' in df:
-        logger.info("Changing Bulk Status")
-        logger.info(f"{df['BulkStatus'].value_counts()}")
-        df.loc[(df['BulkStatus'] == 2), 'BulkStatus'] = 'FU'
-        df.loc[(df['BulkStatus'] == 0), 'BulkStatus'] = 'New'
-        df.loc[(df['BulkStatus'] == 6), 'BulkStatus'] = 'OOO'
-        df.loc[(df['BulkStatus'] == 12), 'BulkStatus'] = 'NN'
-        df.loc[~(df['BulkStatus'].isin([2,0,6,12])),'BulkStatus'] = 'Other'
         logger.info(f"{df['BulkStatus'].value_counts()}")
+        df['is_OOO']=0
+        df.loc[(df['BulkStatus'] == 6), 'is_OOO'] = 1
+        df['is_NN']=0
+        df.loc[(df['BulkStatus'] == 12), 'is_NN'] = 1
+        df.drop(labels=['BulkStatus'],axis=1,inplace=True)
+        logger.info('Deleted BulkStatus column')
+    else:
+        logger.info('Column not present')
     return df
 
 def impute_growth(df,impute_growth_flag=1):
@@ -347,8 +349,6 @@ def impute_growth(df,impute_growth_flag=1):
     return df
     
 
-
-
 def convert_kwkey_specialties_and_technologies_to_int(df):
     """Using regular expressions, converts a comma separated list of keys and technologies into the number of elements of this columns
 
@@ -373,26 +373,30 @@ def convert_kwkey_specialties_and_technologies_to_int(df):
     return df
 
 
-def fill_historic_variables(df):
-    """SQL window functions returns NULLS when there is no data, we reset this to 0
+def fill_variables(df):
+    """fill variables with Nulls
     Args:
         df ([dataframe]): [Dataframe with the leads]
 
     Returns:
         df [dataframe]: [Dataframe with the leads]
     """
-    logger.info(
-        "Filling historic variables ( PContacts, PStatus,Daysince last and first contact)")
-    if 'PreviousContacts' in df:
-        df['PreviousContacts'] = df['PreviousContacts'].fillna(0)
-    if 'PreviousStatus' in df:
-        df['PreviousStatus'] = df['PreviousStatus'].fillna(0)
-        df['PreviousStatus'] = df['PreviousStatus'].astype("category")
-    if 'DaysSinceLastContact' in df:
-        df['DaysSinceLastContact'] = df['DaysSinceLastContact'].fillna(0)
-    if 'DaysSinceFirstContact' in df:
-        df['DaysSinceFirstContact'] = df['DaysSinceFirstContact'].fillna(0)
 
+    variables_dict = {
+        'PreviousContacts':0,
+        'DaysSinceLastContact':0,
+        'DaysSinceFirstContact':0,
+        'NumFoundingRounds':0,
+        'FundingAmount':0,
+        'DaysSinceLastSeed':999999
+    }
+
+    for key in variables_dict.keys():        
+        if key in df:
+            logger.info(f'Filling variable {key} nulls with {variables_dict[key]}')
+            df[key] = df[key].fillna(variables_dict[key])
+        else:
+            logger.info(f'{key} not available to fill')
     return df
 
 
